#define sexp_so_extension ".so"
#define sexp_default_module_path "/usr/local/share/chibi:/usr/local/lib/chibi"
#define sexp_platform "bsd"
#define sexp_version "0.8.0"
#define sexp_release_name "oxygen"
